@@ -15,7 +15,18 @@ sub init {
     $self->{componentsbag} = OnePassBitmapAlgorithmComponentsBag->new;
 }
 
+### NOTE : see pass function below
+sub getBitmap {
+  my $self = shift;
 
+  return $self->{bitmap};
+}
+
+sub getBag {
+  my $self = shift;
+
+  return $self->{componentsbag};
+}
 
 sub pass {
     my ($self, $onepasssystem) = @_;
