@@ -27,7 +27,7 @@ sub indexFunctor {
 }
 
 ### iterates over functors and executes them in the list order
-sub exec {
+sub executeAllFunctors {
     my ($self, $args) = @_;
  
     my $iter = toolsarray->new($self->{functors});
