@@ -16,6 +16,12 @@ sub do {
 
 }
 
+sub getResult {
+  my $self = shift;
+
+  return $self->{result};
+}
+
 sub setResult {
     my ($self, $r) = @_;
 
