@@ -1,4 +1,5 @@
 ### one pass graphics tools
+### this system is used in the onepassbitmapalgorithms
 
 sub new {
     my $class = shift;
@@ -8,11 +9,11 @@ sub new {
     bless $self, $class;
 }
 
+### FIXME run the OnePassAlgorithm or override
 sub run {
-    my ($self, $executable) = @_;
+    my ($self, $algo) = @_;
 
-    ### FIXME run the OnePassAlgorithm
-    
+    return undef;
 }
 
 1;
